@@ -1,6 +1,7 @@
 #include "dclocksettings.h"
 #include <QSettings>
 #include <QVariant>
+#include <QPoint>
 
 /*It's better to use QCoreApplication::setOrganizationName(), QCoreApplication::setOrganizationDomain(),
 and QCoreApplication::setApplicationName(). And then only use QSettings() in any place.
@@ -312,3 +313,78 @@ void dclocksettings::setCornerNumber(const QString &aAplletId, const int &aNumbe
     sett.setValue("CornerNumber",aNumber);
     sett.endGroup();
 }
+
+
+//get show date
+bool dclocksettings::isShowDateEnabled(const QString &aAplletId) const
+{
+    QSettings sett(organizationName,applicationName);
+    sett.beginGroup(aAplletId);
+    return sett.value("ShowDate",false).toBool();
+}
+
+//set show date
+void dclocksettings::setShowDateEnabled(const QString &aAplletId, const bool &aShow) const
+{
+    QSettings sett(organizationName,applicationName);
+    sett.beginGroup(aAplletId);
+    sett.setValue("ShowDate",aShow);
+    sett.endGroup();
+}
+
+//get full date format
+bool dclocksettings::isFullDateFormat(const QString &aAplletId) const
+{
+    QSettings sett(organizationName,applicationName);
+    sett.beginGroup(aAplletId);
+    return sett.value("FullDate",false).toBool();
+}
+
+//set full date format
+void dclocksettings::setFullDateFormat(const QString &aAplletId, const bool &aFull) const
+{
+    QSettings sett(organizationName,applicationName);
+    sett.beginGroup(aAplletId);
+    sett.setValue("FullDate",aFull);
+    sett.endGroup();
+}
+
+//get date size
+int dclocksettings::getDateSize(const QString &aAplletId) const
+{
+    QSettings sett(organizationName,applicationName);
+    sett.beginGroup(aAplletId);
+    return sett.value("DateSize",20).toInt();
+}
+
+//set date size
+void dclocksettings::setDateSize(const QString &aAplletId, const int &aSize) const
+{
+    QSettings sett(organizationName,applicationName);
+    sett.beginGroup(aAplletId);
+    sett.setValue("DateSize",aSize);
+    sett.endGroup();
+}
+
+//get widget's position
+// to remember widget's position when it's removed from today
+/*QPoint dclocksettings::getPosition(const QString &aAplletId) const
+{
+    QSettings sett(organizationName,applicationName);
+    sett.beginGroup(aAplletId);
+    int x = sett.value("PositionX",0).toInt();
+    int y = sett.value("PositionY",0).toInt();
+    sett.endGroup();
+    return QPoint(x,y);
+}
+
+//set widget's position
+void dclocksettings::setPosition(const QString &aAplletId, const QPoint &aPos) const
+{
+    QSettings sett(organizationName,applicationName);
+    sett.beginGroup(aAplletId);
+    sett.setValue("PositionX",aPos.x());
+    sett.setValue("PositionY",aPos.y());
+    sett.endGroup();
+}
+*/
